package com.abi.qms.platform.service;


import com.abi.qms.platform.dto.req.AddInspectionCaseReq;
import com.abi.qms.platform.dto.req.AssociatedWithCaseReq;
import com.abi.qms.platform.dto.req.EditInspectionCaseReq;
import com.abi.qms.platform.dto.req.PageListInspectionCaseReq;
import com.abi.qms.platform.dto.res.GetCaseBoxCodeListRes;
import com.abi.qms.platform.dto.res.GetInspectionCaseInfoRes;
import com.abi.qms.platform.dto.res.PageListInspectionCaseRes;
import com.abi.qms.platform.dto.res.QueryCaseLikeNumOrNameRes;

import java.util.Collection;
import java.util.List;

/**
 * 稽查案件 Service接口
 *
 * @author ruoyi
 * @date 2021-07-19
 */
public interface IInspectionCaseService {

    /**
     * 新增案件
     *
     * @param addReq 新增请求
     */
    void addInspectionCase(AddInspectionCaseReq addReq);

    /**
     * 分页列表查询
     *
     * @param pageListReq 查询条件和分页信息
     * @return 查询结果
     */
    PageListInspectionCaseRes pageListQuery(PageListInspectionCaseReq pageListReq);

    /**
     * 编辑案件
     *
     * @param editReq 编辑内容
     */
    void editInspectionCase(EditInspectionCaseReq editReq);

    /**
     * 删除指定案件
     *
     * @param ids 指定案件ids
     */
    void removeInspectionCase(Long[] ids);


    /**
     * 获取案件详情信息
     *
     * @param id ID
     * @return 案件详情信息
     */
    GetInspectionCaseInfoRes getInspectionCaseInfo(Long id);

    /**
     * 根据案件编号 或者名称  模糊查询
     *
     * @param numOrName 编号或名称
     * @return 案件信息
     */
    QueryCaseLikeNumOrNameRes queryCaseLikeNumOrName(final String numOrName);

    /**
     * 关联案件
     *
     * @param req 请求
     */
    void associatedWithCase(AssociatedWithCaseReq req);

    /**
     * 查询涉案箱码列表
     *
     * @param caseId 案件ID
     * @return 箱码列表
     */
    GetCaseBoxCodeListRes getBoxCodeListByCaseId(final Long caseId);
}
